==> hdb-0.00.tar.gz: hdb-0.00/hdbapp.h <==
/* hdbapp.h
** hdb application header
** wcm, 2010.05.28 - 2010.12.15
** ===
*/

#ifndef HDBAPP_H
#define HDBAPP_H 1

/* libasagna: */
#include "die.h"
#include "ioq.h"
#include "ioq_std.h"
#include "sysstr.h"
/* libasagna hdb (for HDB32_IDENT): */
#include "hdb.h"

#ifndef HDBAPP_VERSION
#define HDBAPP_VERSION "0.00"
#endif

/* default extension for temporary files: */
#ifndef HDBAPP_TMPEXT
#define HDBAPP_TMPEXT  ".{new}"
#endif

/* defined non-NULL for all hdbapp_*.c: */
extern const char *progname;
extern const char *usage_prog;

/* defined non-NULL only by hdbapp_master.c */
extern const char *progmode;
extern const char *usage_mode;


/* using ioq_std for stderr output: */
#define eputs(...) \
  {ioq_vputs(ioq2, __VA_ARGS__, "\n"); ioq_flush(ioq2); }

#define usage() \
  {\
      if(progmode != NULL){\
          eputs("usage: ", progname, " ", progmode, " ", usage_mode);\
       }else{\
          eputs("usage: ", progname, " ", usage_prog);\
       }\
  }
  

#define version() \
  eputs(progname, ": version: ", HDBAPP_VERSION, " (", HDB32_IDENT, ")");

#define die_usage() \
  {usage(); die(100);}

#define warn(...) \
  {\
      if(progmode != NULL){\
          eputs(progname, " ", progmode, ": warning: ", __VA_ARGS__);\
      }else{\
          eputs(progname, ": warning: ", __VA_ARGS__);\
      }\
  }

#define fatal(e, ...) \
  {\
      if(progmode != NULL){\
          eputs(progname, " ", progmode, ": fatal: ", __VA_ARGS__);\
      }else{\
          eputs(progname, ": fatal: ", __VA_ARGS__);\
      }\
      die(e);\
  }

#define fatal_syserr(...) \
  fatal(111, __VA_ARGS__, ": ", \
        sysstr_errno_mesg(errno), " (", \
        sysstr_errno(errno), ")")

#define fatal_usage(...) \
  {\
      if(progmode != NULL){\
          eputs(progname, " ", progmode, ": usage error: ", __VA_ARGS__);\
      }else{\
          eputs(progname, ": usage error: ", __VA_ARGS__);\
      }\
      die_usage();\
  }


#if 0
#define debug(...) \
  eputs("debug: ", __VA_ARGS__)
#endif
#define debug(...)


/* hdbapp modules ("modes"): */
extern int hdbapp_cross(int argc, char *argv[]);
extern int hdbapp_dump(int argc, char *argv[]);
extern int hdbapp_dupes(int argc, char *argv[]);
extern int hdbapp_get(int argc, char *argv[]);
extern int hdbapp_grep(int argc, char *argv[]);
extern int hdbapp_keys(int argc, char *argv[]);
extern int hdbapp_make(int argc, char *argv[]);
extern int hdbapp_match(int argc, char *argv[]);
extern int hdbapp_merge(int argc, char *argv[]);
extern int hdbapp_purge(int argc, char *argv[]);
extern int hdbapp_stats(int argc, char *argv[]);


#endif /* HDBAPP_H */
/* eof (hdbapp.h) */

==> hdb-0.01.tar.gz: hdb-0.01/hdbapp.h <==
/* hdbapp.h
** hdb application header
** wcm, 2010.05.28 - 2010.12.17
** ===
*/

#ifndef HDBAPP_H
#define HDBAPP_H 1

/* libasagna: */
#include "die.h"
#include "ioq.h"
#include "ioq_std.h"
#include "sysstr.h"
/* libasagna hdb (for HDB32_IDENT): */
#include "hdb.h"

#ifndef HDBAPP_VERSION
#define HDBAPP_VERSION "0.00"
#endif

/* default extension for temporary files: */
#ifndef HDBAPP_TMPEXT
#define HDBAPP_TMPEXT  ".{new}"
#endif

/* defined non-NULL for all hdbapp_*.c: */
extern const char *progname;
extern const char *usage_prog;

/* defined non-NULL only by hdbapp_master.c */
extern const char *progmode;
extern const char *usage_mode;


/* using ioq_std for stderr output: */
#define eputs(...) \
  {ioq_flush(ioq1); ioq_vputs(ioq2, __VA_ARGS__, "\n"); ioq_flush(ioq2); }

#define usage() \
  {\
      if(progmode != NULL){\
          eputs("usage: ", progname, " ", progmode, " ", usage_mode);\
       }else{\
          eputs("usage: ", progname, " ", usage_prog);\
       }\
  }
  

#define version() \
  eputs(progname, ": version: ", HDBAPP_VERSION, " (", HDB32_IDENT, ")");

#define die_usage() \
  {usage(); die(100);}

#define warn(...) \
  {\
      if(progmode != NULL){\
          eputs(progname, " ", progmode, ": warning: ", __VA_ARGS__);\
      }else{\
          eputs(progname, ": warning: ", __VA_ARGS__);\
      }\
  }

#define fatal(e, ...) \
  {\
      if(progmode != NULL){\
          eputs(progname, " ", progmode, ": fatal: ", __VA_ARGS__);\
      }else{\
          eputs(progname, ": fatal: ", __VA_ARGS__);\
      }\
      die(e);\
  }

#define fatal_syserr(...) \
  fatal(111, __VA_ARGS__, ": ", \
        sysstr_errno_mesg(errno), " (", \
        sysstr_errno(errno), ")")

#define fatal_usage(...) \
  {\
      if(progmode != NULL){\
          eputs(progname, " ", progmode, ": usage error: ", __VA_ARGS__);\
      }else{\
          eputs(progname, ": usage error: ", __VA_ARGS__);\
      }\
      die_usage();\
  }


#if 0
#define debug(...) \
  eputs("debug: ", __VA_ARGS__)
#endif
#define debug(...)


/* hdbapp modules ("modes"): */
extern int hdbapp_about(int argc, char *argv[]);
extern int hdbapp_cross(int argc, char *argv[]);
extern int hdbapp_dump(int argc, char *argv[]);
extern int hdbapp_dupes(int argc, char *argv[]);
extern int hdbapp_get(int argc, char *argv[]);
extern int hdbapp_grep(int argc, char *argv[]);
extern int hdbapp_keys(int argc, char *argv[]);
extern int hdbapp_make(int argc, char *argv[]);
extern int hdbapp_match(int argc, char *argv[]);
extern int hdbapp_merge(int argc, char *argv[]);
extern int hdbapp_purge(int argc, char *argv[]);
extern int hdbapp_stats(int argc, char *argv[]);


#endif /* HDBAPP_H */
/* eof (hdbapp.h) */
